@@ -43,7 +43,7 @@ class Exists(tc.Formula):
                 f"\\text{{{self.variable.name}}} \\in \\text{{{self.variable.type}}}"
             )
 
-        return f"\\exists_{{{forall_str}}}(type_str \\land ({self.children[0]}))"
+        return f"\\exists_{{{forall_str}}}({type_str} \\land ({self.children[0]}))"
 
     @typechecked
     def __eq__(self, other) -> bool:
